import { Client } from '../client';
import { BaseError } from '../errors/baseError';
import { UriHelper, HandlerQuery } from '../uri-helper';
import { ThBaseHandler } from '../base';
import { Pricebooks } from './pricebooks';
import { PricebookEntries } from './pricebook-entries';
export interface Images {
    '1x'?: string;
    avatar?: string;
}
declare type ProductTypes = 'product' | 'voucher' | 'linked' | 'linked_product' | 'variant' | 'variant_product';
export interface Product {
    id?: string;
    name?: string;
    description?: string | null;
    attributes?: Record<string, unknown> | null;
    parent?: string | null;
    parent_custom_id?: string | null;
    tags?: any[] | null;
    linked_products?: any[] | null;
    prices?: Record<string, unknown>;
    barcode?: string | null;
    codes?: any[] | null;
    sku?: string | null;
    stock_minimum?: number | null;
    stock_maximum?: number | null;
    stockable?: boolean | null;
    metadata?: Record<string, unknown> | null;
    audiences?: any[] | null;
    keywords?: any[] | null;
    categories?: any[] | null;
    related_to?: any[] | null;
    similar_to?: any[] | null;
    released_at?: string | null;
    purchased_at?: string | null;
    produced_at?: string | null;
    custom_id?: string | string[] | null;
    tax?: string;
    taxes_options?: any[] | Record<string, unknown> | null;
    season?: string | null;
    seasons?: Record<string, unknown> | null;
    account?: string;
    vat_class?: string | null;
    category?: string | null;
    brand?: string | null;
    active?: boolean;
    deleted?: boolean;
    type?: ProductTypes;
    manufacturer?: Record<string, unknown> | null;
    supplier?: Record<string, unknown> | null;
    condition?: string | null;
    images?: Images | null;
    summary?: string | null;
    insert_id?: number;
    product_group?: string | null;
    delegated_to?: string[] | null;
    stock_mode?: string | null;
    stock_configuration_location?: StockConfigurationLocation | null;
    reorder_point?: number | null;
    reorder_qty?: number | null;
    locations?: string[] | null;
    stock_info?: Record<string, unknown> | null;
    i18n?: Record<string, unknown> | null;
    is_service?: boolean;
    delegateable?: boolean;
    delegateable_to?: Array<Record<string, unknown>>;
    delegated_from?: Record<string, unknown>;
}
export interface StockConfigurationLocation {
    location?: string | null;
    stockable?: boolean | null;
    stock_minimum?: number | null;
    reorder_qty?: number | null;
    reorder_point?: number | null;
}
export interface ProductsQuery {
    deleted?: boolean;
    active?: boolean;
    exclude_system_products?: boolean;
    location?: string;
    extended?: boolean;
    [key: string]: any;
}
export interface SelectProductsQuery {
    product_ids?: string[];
    custom_ids?: string[];
    query?: {
        deleted?: boolean;
        exclude_system_products?: boolean;
        types?: ProductTypes[];
    };
}
export interface ProductsExportResponse {
    data?: {
        url?: string;
        filename?: string;
        expiresAt?: string;
    };
    msg?: string;
}
export interface ProductsOptions {
    user?: string;
    base?: string;
    limit?: number;
    uri?: string;
    query?: ProductsQuery;
}
export interface ProductsDetailsOptions {
    stockLocation?: string;
    stockFilters?: string;
    shortOnStock?: number;
}
export interface ProductDeleteOptions {
    delete_dependencies?: boolean;
}
export interface ProductsResponse {
    data?: Product[];
    metadata?: Record<string, unknown>;
    msg?: string;
    next?: () => Promise<ProductsResponse>;
}
export interface ProductsBulkResponse {
    results?: {
        updated_products?: Product[];
        invalid_products?: Product[];
        invalid_stock?: Product[];
        count?: number;
    };
    msg?: string;
}
export interface ProductResponse {
    data: Product;
    metadata?: {
        count?: number;
        patch?: any;
    };
    msg?: string;
    errors?: ErrorObject[];
}
export interface ProductsDuplicateResponse {
    data: Product[];
    metadata?: {
        count?: number;
        patch?: any;
    };
    msg?: string;
    errors?: ErrorObject[];
}
export interface ProductsDuplicateBody {
    productIds: string[];
}
export interface ErrorObject {
    id: string;
    label: string;
    errorDetails: Record<string, unknown>;
}
export interface ProductsCreateQuery {
    product_id_template?: string;
    generate_product_id?: boolean;
}
export interface ProductsBulkDeleteBody {
    productIds: string[];
}
export interface HandlerProductsQuery extends HandlerQuery {
    query?: ProductsCreateQuery;
}
export interface ProductsUpdateRequestObject {
    productId: string;
    body: Product;
}
export interface SearchQuery {
    q: string;
    types?: ProductTypes[];
}
export interface BookStockQuery {
    productId: string;
    body: BookStock;
}
export interface BookStock {
    location: string;
    qty: number;
}
export interface BarcodeResponse {
    barcode?: string;
    id?: string;
    name?: string;
    codes?: Array<Record<string, unknown>>;
}
export declare class Products extends ThBaseHandler {
    static baseEndpoint: string;
    endpoint: string;
    http: Client;
    options: ProductsOptions;
    uriHelper: UriHelper;
    constructor(options: ProductsOptions, http: Client);
    create(product: Product, query?: HandlerProductsQuery): Promise<ProductResponse>;
    duplicate(body: ProductsDuplicateBody): Promise<ProductsDuplicateResponse>;
    getAll(options?: ProductsOptions | undefined): Promise<ProductsResponse>;
    select(options: SelectProductsQuery): Promise<ProductsResponse>;
    import(options?: ProductsOptions | undefined): Promise<ProductsResponse>;
    get(productId: string): Promise<ProductResponse>;
    export(query?: ProductsQuery | undefined): Promise<ProductsExportResponse>;
    getDetails(productId: string, options?: ProductsOptions | undefined): Promise<ProductResponse>;
    getChildrenDetails(productId: string, hideStock?: boolean, options?: ProductsDetailsOptions | undefined): Promise<ProductResponse>;
    meta(q?: ProductsQuery | undefined): Promise<ProductsResponse>;
    put(productId: string, product: Product): Promise<ProductResponse>;
    bulkCreate(products: Product[], query?: HandlerProductsQuery): Promise<ProductsBulkResponse>;
    bulkEdit(products: Product[]): Promise<ProductsResponse>;
    bulkDelete(body: ProductsBulkDeleteBody): Promise<ProductsResponse>;
    count(): Promise<ProductsResponse>;
    delete(productId: string, deleteOptions?: ProductDeleteOptions): Promise<ProductsResponse>;
    search(query: SearchQuery | string): Promise<ProductsResponse>;
    bookStock(requestOptions: BookStockQuery): Promise<ProductResponse>;
    checkBarcode(code: string): Promise<ProductResponse>;
    pricebooks(): Pricebooks;
    pricebookEntries(): PricebookEntries;
}
export declare class ProductsCreateFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsDuplicateFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductFetchFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsFetchFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsImportFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsExportFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductDetailsFetchFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductChildrenDetailsFetchFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsCountFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsMetaFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsUpdateFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsBulkCreateFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsBulkEditFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsBulkDeleteFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsDeleteFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsSearchFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class ProductsBookStockFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export declare class BarcodeGetFailed extends BaseError {
    message: string;
    name: string;
    constructor(message?: string, properties?: Record<string, unknown>);
}
export {};
